@@ -68,7 +68,6 @@ _BASE_PROVIDERS = [
     'aspews.ext.sorbs.net',
     'b.barracudacentral.org',
     'bl.nordspam.com',
-    'bl.spamcop.net',
     'blackholes.five-ten-sg.com',
     'blacklist.woody.ch',
     'bogons.cymru.com',
@@ -79,17 +78,14 @@ _BASE_PROVIDERS = [
     'dnsbl-2.uceprotect.net',
     'dnsbl-3.uceprotect.net',
     'dnsbl.cyberlogic.net',
-    'dnsbl.dronebl.org',
     'dnsbl.sorbs.net',
     'drone.abuse.ch',
     'dul.ru',
-    'dyna.spamrats.com',
     'images.rbl.msrbl.net',
     'ips.backscatterer.org',
     'ix.dnsbl.manitu.net',
     'korea.services.net',
     'matrix.spfbl.net',
-    'noptr.spamrats.com',
     'phishing.rbl.msrbl.net',
     'proxy.bl.gweep.ca',
     'proxy.block.transip.nl',
@@ -102,7 +98,6 @@ _BASE_PROVIDERS = [
     'singular.ttk.pte.hu',
     'spam.dnsbl.sorbs.net',
     'spam.rbl.msrbl.net',
-    'spam.spamrats.com',
     'spambot.bls.digibase.ca',
     'spamlist.or.kr',
     'spamrbl.imp.ch',
